(confirm-parse-output parse-result)Either raise a condition on parse error, or allow parse-result to pass through.
Either raise a condition on parse error, or allow parse-result to pass through.
(parse template-str delimiters)Tokenize a template string into a sequence of tokens suitable for parsing.
Each lexeme is any of:
Tokenize a template string into a sequence of tokens suitable for parsing. Each lexeme is any of: - Template content, as a string. - Template delimiter, as a Clojure keyword.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |